/*
 * COPYRIGHT (c) 1986-1996 Adobe Systems Incorporated.
 *
 * This source code contained herein is proprietary and
 * confidential information of Adobe Systems Incorporated
 * and is covered by the U.S. and other copyright and trade
 * secret protection.  Unauthorized adaptation, distribution,
 * use or display is prohibited and may be subject to civil
 * and criminal penalties.  Disclosure to others is prohibited.
 * For the terms and conditions of source code use refer to
 * your Adobe Systems Incorporated Source Code License Agreement.
 */

#ifndef FCHANNEL_H
#define FCHANNEL_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef UNIX
/***************************************************************************
  private definition of the ChannelT data struct 
*/ 

struct _masterChannelT {
  BoolT      swap; 
  StringT    platformPath;       
  StreamT    stream;
};

typedef struct _masterChannelT PrivateChannelT;

/***********************************************************************
  Access macros for ChannelT structure. 
  This will hide the implementation details of ChannelT from the user.

***********************************************************************/ 
#define FdeChannelNew() \
	(ChannelT) F_Calloc(1, sizeof(PrivateChannelT), NO_DSE)

#define FdeChannelGetStream(Channel)   ((Channel)->stream)
#define FdeChannelGetPathName(Channel) ((Channel)->platformPath)
#define FdeChannelGetSwap(Channel) ((Channel)->swap)

#define FdeChannelSetPathName(Channel, path) (((Channel)->platformPath) = (path))
#define FdeChannelSetStream(Channel, stream_v) (((Channel)->stream) = (stream_v))
#define FdeChannelSetSwap(Channel, Swap) (((Channel)->swap) = (Swap))

#endif /* UNIX */

/****************************************************************************
  channel functions 
*/
#if defined(FAPI_5_BEHAVIOR) || defined(FAPI_4_BEHAVIOR)
extern ChannelT F_ChannelOpen FARGS((FilePathT *path, StringT type));
#else
extern ChannelT F_ChannelOpen FARGS((FilePathT *path, CStringT type));
#endif
extern ChannelT F_ChannelMakeTmp FARGS((PUCharT size));
extern IntT F_ChannelRead FARGS((PtrT ptr, IntT size, IntT nitems, ChannelT channel));
extern IntT F_ChannelWrite FARGS((ConPtrT ptr, IntT size, IntT nitems,
	ChannelT channel));
extern IntT FdeChannelClose FARGS((ChannelT *channel));
extern IntT F_ChannelClose FARGS((ChannelT channel));
extern IntT FdeChannelCloseTmp FARGS((ChannelT *channel));
extern IntT F_ChannelCloseTmp FARGS((ChannelT channel));
extern IntT F_ChannelSeek FARGS((ChannelT channel, NativeLongT offset,
	PUCharT mode));
extern IntT F_ChannelPeek FARGS((ChannelT channel));
extern NativeLongT F_ChannelTell FARGS((ChannelT channel));
extern NativeLongT F_ChannelSize FARGS((ChannelT channel));
extern ErrorT F_ChannelAppend FARGS((ChannelT srcChannel, ChannelT dstChannel));
extern IntT F_ChannelFlush FARGS((ChannelT channel));
extern IntT F_ChannelEof FARGS((ChannelT channel));


#ifdef __cplusplus
}
#endif

#endif /* FCHANNEL_H */
