/*
 * COPYRIGHT (c) 1986-1996 Adobe Systems Incorporated.
 *
 * This source code contained herein is proprietary and
 * confidential information of Adobe Systems Incorporated
 * and is covered by the U.S. and other copyright and trade
 * secret protection.  Unauthorized adaptation, distribution,
 * use or display is prohibited and may be subject to civil
 * and criminal penalties.  Disclosure to others is prohibited.
 * For the terms and conditions of source code use refer to
 * your Adobe Systems Incorporated Source Code License Agreement.
 */

#ifndef FCHARMAP_H
#define FCHARMAP_H

/*
 * Useful character codes.
 * These are rendered in FrameMaker's internal character encoding,
 * which differs from ASCII at several points, e.g., FC_EOL (newline)
 * is 0x09 rather than the usual 0x0A.
 */

/* Breaks */
#define	FC_UTILITY	0x01	/* Used by search and index */
#define FC_DBREAK	0x02	/* Discretionary break */
#define FC_NBREAK	0x03	/* Suppress this break */
#define	FC_DHYPHEN	0x04	/* Discretionary hyphen */
#define	FC_NHYPHEN	0x05	/* Suppress this h-point */
#define	FC_HYPHEN	0x06	/* Temporary hyphen */

/* Control-character codes */
#define	FC_TAB		0x08  
#define	FC_EOL		0x09	/* Hard return */
#define	FC_EOP		0x0A 	/* End of para */
#define	FC_EOD		0x0B	/* End of flow */

/* Unstretchable spaces */
#define FC_SPACE_NUMBER	0x10	/* Number space */
#define	FC_SPACE_HARD	0x11	/* Hard space   */
#define FC_SPACE_THIN	0x12	/* Thin == 1/12 em */
#define FC_SPACE_EN	0x13	/* En   == 1/2 em */
#define FC_SPACE_EM	0x14	/* Em   == 1 em */

#define FC_HYPHEN_HARD	0x15	/* Unbreakable explicit hyphen */

/* Block sentinels */
#define	FC_ESC		0x1B   /* sentinel code for cblocks */
#define	FC_SCH		0x1C   /* sentinel code for sblocks */

/* Convenient names */
#define	FC_SPACE		0x20   /* ' ' regular space */
#define FC_QUOTEDBL		0x22   /* '"' straight double quote */
#define FC_QUOTESINGLE		0x27   /* '\'' straight single quote */
#define FC_BACKSLASH		0x5c   /* '\\' Backslash             */
#define FC_GUILLEMOTLEFT	0xc7   /* guillemotleft */
#define FC_GUILLEMOTRIGHT	0xc8   /* guillemotright */
#define FC_QUOTEDBLLEFT		0xd2   /* curly double left quote    */
#define FC_QUOTEDBLRIGHT	0xd3   /* curly double right quote   */
#define FC_QUOTELEFT		0xd4   /* curly single left quote    */
#define FC_QUOTERIGHT		0xd5   /* curly single right quote   */
#define FC_GUILSINGLLEFT	0xdc   /* guillemotleft */
#define FC_GUILSINGLRIGHT	0xdd   /* guillemotright */
#define FC_QUOTESINGLBASE	0xe2   /* quotesinglbase */
#define FC_QUOTEDBLBASE		0xe3   /* quotedblbase */

/* Useful metachar display code names */
#define	FC_CENT		0xa2
#define	FC_POUND	0xa3
#define	FC_YEN		0xb4
#define	FC_ENDASH	0xd0
#define	FC_DAGGER	0xa0
#define	FC_DAGGERDBL	0xe0
#define	FC_BULLET	0xa5
#define	FC_EMDASH	0xd1
#ifndef FC_META
#define FC_META		0x80
#endif

#define FC_CONTROL	0x001
#define FC_UPPERCASE	0x002
#define	FC_LOWERCASE	0x004
#define FC_ALPHABETIC	0x008
#define FC_NUMERIC	0x010
#define FC_HEXADECIMAL	0x020
#define FC_INVISIBLE  0x040
#define FC_WORDBREAK	0x080
#define	FC_INWORD	0x100
#define FC_ENDOFLINE	0x200
#define FC_ENDOFSATZ	0x400
#define FC_INDEXABLE	0x800
#define FC_BREAK	0x1000
#define FC_BEFORELQ	0x2000
#define FC_CONSONANT	0x4000

#define F_CharIsUpper(c)	(FdeCharProps[(UCharT)(c)]&FC_UPPERCASE)
#define F_CharIsLower(c)	(FdeCharProps[(UCharT)(c)]&FC_LOWERCASE)
#define F_CharIsEol(c)		(FdeCharProps[(UCharT)(c)]&FC_ENDOFLINE)
#define F_CharIsControl(c)	(FdeCharProps[(UCharT)(c)]&FC_CONTROL)
#define F_CharIsAlphabetic(c)	(FdeCharProps[(UCharT)(c)]&FC_ALPHABETIC)
#define F_CharIsNumeric(c)	(FdeCharProps[(UCharT)(c)]&FC_NUMERIC)
#define F_CharIsAlphaNumeric(c)	(FdeCharProps[(UCharT)(c)]&(FC_NUMERIC|FC_ALPHABETIC))
#define F_CharIsHexadecimal(c)	(FdeCharProps[(UCharT)(c)]&FC_HEXADECIMAL)
#define F_CharIsInWord(c)       (FdeCharProps[(UCharT) (c)]&FC_INWORD)

#define F_CharToUpper(c)	(FdeMToUpper[(UCharT)(c)])
#define F_CharToLower(c)	(FdeMToLower[(UCharT)(c)])

#define F_Hex2AtoD(msn9,lsn9)\
((FdeHexAtoD[(UCharT) (msn9)]<<4) | FdeHexAtoD[(UCharT) (lsn9)])
#define F_HexDto2A(i9,msn9,lsn9)\
((msn9)=FdeHexDtoA[((UCharT)(i9))>>4], (lsn9)=FdeHexDtoA[((UCharT)(i9))&0xF])

#ifdef __cplusplus
extern "C" {
#endif

extern const UCharT *FdeIdentMap;
extern const UCharT *FdeMToUpper;
extern const UCharT *FdeMToLower;
extern const UCharT *FdeHexDtoA;
extern const UCharT *FdeHexAtoD;
extern const UShortT *FdeCharProps;
extern const UCharT *FdeMToAnMap;
extern const UCharT *FdeAnToMMap;

#ifdef __cplusplus
}
#endif

#endif /* FCHARMAP_H */
