
#include <afxdisp.h>
#include "debuglog.h"

OLECHAR* makeOLEstring(char*);
LPDISPATCH olesrv = NULL;

extern int frame2ps(char*, char*);

int diffVer(char* ftype, char* msfile1, char* msfile2, char* pdffile)
{
	HRESULT hr;
	CLSID clsid;		//  CLSID of ms2pdf object
	LPUNKNOWN punk = NULL;	//  IUnknown of ms2pdf object
	LPDISPATCH olesrv;

	if (strcmp(ftype, "msdiff"))
	{
		/*
		**	We do not have ole automation for FrameMaker
		**	but we have an api we can access (non-vb), so,
		**	Generate ps file in c:\distOut.ps
		*/
		debuglog("We can only diff msword now\n");
		errormsg("We can only diff msword now\n");
		return 1;
		
	}
	
	/*
	**	Initialize OLE.
	*/
	hr = OleInitialize(NULL);
	if (FAILED(hr))
	{
		debuglog("Can't initialize OLE.\n");
		errormsg("Can't initialize OLE.");
		return 1;
	}

	if (!SetMessageQueue(96))
	{
		debuglog("Can't increase message queue.\n");
		errormsg("Can't increase OLE message queue.");
		return 1;
	}

	/*
	**	Retrieve the class id from the prog ID for OleSrv.
	*/
	hr = CLSIDFromProgID(OLESTR("OleSrv.ms2pdf"), &clsid);
	if (FAILED(hr))
	{
		debuglog("Can't get CLSID for olesrvr.OleSrv!\n");
		errormsg("Can't get CLSID for olesrvr.OleSrv!");
		OleUninitialize();
		return 1;
	}

	/*
	**	Create an instance of the OleSrv object.
	*/
	hr = CoCreateInstance(clsid, NULL, CLSCTX_SERVER, IID_IUnknown,
		(void FAR* FAR*)&punk);
	if (FAILED(hr))
	{
		
		debuglog("Can't create instance of olesrvr.OleSrv object! %d\n",
			hr);
		errormsg("Can't create instance of olesrvr.OleSrv object!");
		OleUninitialize();
		return 1;
	}

	/*
	**	Get a pointer to the OleSrv IDispatch interface.
	*/
	hr = punk->QueryInterface(IID_IDispatch, (void FAR* FAR*)&olesrv);
	if (FAILED(hr))
	{
		debuglog("Can't get pointer to OleSrv idispatch intf!\n");
		errormsg("Can't get pointer to OleSrv idispatch intf!");
		OleUninitialize();
		return 1;
	}

	punk->Release();	//Release - no longer needed.

	/*
	**	Invoke the ms2pdf method.
	*/
	DISPID dispid1;
	DISPPARAMS disp1;
	VARIANTARG varg1[5];
	BSTR szName;

	szName = L"diffdocs";

	int MaxParms = 3;
	int i;

	for(i = 0; i < MaxParms; i++)
	{
		VariantInit(&varg1[i]);
	}

	/*
	*/
	OLECHAR FAR* Omsfile1 = makeOLEstring(msfile1);
	V_VT(&varg1[2])      = VT_BSTR;
	V_BSTR(&varg1[2])    = SysAllocString(Omsfile1);

	OLECHAR FAR* Omsfile2 = makeOLEstring(msfile2);
	V_VT(&varg1[1])      = VT_BSTR;
	V_BSTR(&varg1[1])    = SysAllocString(Omsfile2);

	OLECHAR FAR* Opdffile = makeOLEstring(pdffile);
	V_VT(&varg1[0])      = VT_BSTR;
	V_BSTR(&varg1[0])    = SysAllocString(Opdffile);

	disp1.rgvarg = varg1;
	disp1.rgdispidNamedArgs = NULL;
	disp1.cArgs = MaxParms;
	disp1.cNamedArgs = 0;

	/*
	**	Get ID for diffVer method.
	*/
	hr = olesrv->GetIDsOfNames(IID_NULL, &szName, 1, LOCALE_SYSTEM_DEFAULT,
		&dispid1);
	if (FAILED(hr))
	{
		debuglog("Can't get ID for %s method!\n", ftype);
		errormsg("Can't get ID for %s method!", ftype);
		OleUninitialize();
		return 1;
	}

	hr = olesrv->Invoke(dispid1, IID_NULL, LOCALE_SYSTEM_DEFAULT,
		DISPATCH_METHOD, &disp1, NULL, NULL, NULL);

	if (hr == S_OK)
	{
		debuglog("%s: OK.\n", ftype);
	}
	else
	{
		if (hr == DISP_E_BADPARAMCOUNT)
		{
			debuglog("%s: bad parameter count.\n", ftype);
			errormsg("%s: bad parameter count.", ftype);
		}
		else if (hr == DISP_E_BADVARTYPE)
		{
			debuglog("%s: arg is invalid variant type.\n", ftype);
			errormsg("%s: arg is invalid variant type.", ftype);
		}
		else if (hr == DISP_E_EXCEPTION)
		{
			debuglog("%s: caught an exception.\n", ftype);
			errormsg("%s: caught an exception.", ftype);
		}
		else if (hr == DISP_E_MEMBERNOTFOUND)
		{
			debuglog("%s: member nonexistent or improper value.\n",
				ftype);
			errormsg("%s: member nonexistent or improper value.",
				ftype);
		}
		else if (hr == DISP_E_NONAMEDARGS)
		{
			debuglog("%s: named args not supported.\n", ftype);
			errormsg("%s: named args not supported.\n", ftype);
		}
		else if (hr == DISP_E_OVERFLOW)
		{
			debuglog(
			     "%s: a value could not be converted to type.\n",
		 	     ftype);
			errormsg(
			     "%s: a value could not be converted to type.",
		 	     ftype);
		}
		else if (hr == DISP_E_PARAMNOTFOUND)
		{
			debuglog("%s: parameter is invalid.\n", ftype);
			errormsg("%s: parameter is invalid.", ftype);
		}
		else if (hr == DISP_E_TYPEMISMATCH)
		{
			debuglog("%s: arg can't be coerced.\n", ftype);
			errormsg("%s: arg can't be coerced.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNINTERFACE)
		{
			debuglog("%s: can't get this error msg.\n", ftype);
			errormsg("%s: can't get this error msg.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNLCID)
		{
			debuglog("%s: unrecognized local id.\n", ftype);
			errormsg("%s: unrecognized local id.", ftype);
		}
		else if (hr == DISP_E_PARAMNOTOPTIONAL)
		{
			debuglog("%s: a required param was omitted.\n", ftype);
			errormsg("%s: a required param was omitted.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNNAME)
		{
			debuglog("%s: unknown name.\n", ftype);
			errormsg("%s: unknown name.", ftype);
		}
		else if (hr == DISP_E_BADINDEX)
		{
			debuglog("%s: bad index.\n", ftype);
			errormsg("%s: bad index.", ftype);
		}
		else if (hr == DISP_E_ARRAYISLOCKED)
		{
			debuglog("%s: array is locked.\n", ftype);
			errormsg("%s: array is locked.", ftype);
		}
		else if (hr == DISP_E_BADCALLEE)
		{
			debuglog("%s:  bad callee.\n", ftype);
			errormsg("%s:  bad callee.", ftype);
		}
		else if (hr == DISP_E_NOTACOLLECTION)
		{
			debuglog("%s: not a collection.\n", ftype);
			errormsg("%s: not a collection.", ftype);
		}
		else 
		{
			debuglog("%s:  some crazy return!\n", ftype);
			errormsg("%s:  some crazy return!", ftype);
		}

		olesrv->Release();
		OleUninitialize();
		return 1;
	}

	for (i = 0; i < MaxParms; i++)
	{
		VariantClear(&varg1[i]);
	}

	olesrv->Release();
	OleUninitialize();
	return 0;
}

int ms2pdf(char* ftype, char* msfile, char* pdffile)
{
	HRESULT hr;
	CLSID clsid;		//  CLSID of ms2pdf object
	LPUNKNOWN punk = NULL;	//  IUnknown of ms2pdf object
	LPDISPATCH olesrv;

	if (strncmp(ftype, "frame", 5) == 0)
	{
		/*
		**	We do not have ole automation for FrameMaker
		**	but we have an api we can access (non-vb), so,
		**	Generate ps file in c:\distOut.ps
		*/
		int ret = frame2ps(ftype, msfile);
		if (ret != 0)
		{
			return 1;
		}
	}
	
	/*
	**	Initialize OLE.
	*/
	hr = OleInitialize(NULL);
	if (FAILED(hr))
	{
		debuglog("Can't initialize OLE.\n");
		errormsg("Can't initialize OLE.");
		return 1;
	}

	if (!SetMessageQueue(96))
	{
		debuglog("Can't increase message queue.\n");
		errormsg("Can't increase OLE message queue.");
		return 1;
	}

	/*
	**	Retrieve the class id from the prog ID for OleSrv.
	*/
	hr = CLSIDFromProgID(OLESTR("OleSrv.ms2pdf"), &clsid);
	if (FAILED(hr))
	{
		debuglog("Can't get CLSID for olesrvr.OleSrv!\n");
		errormsg("Can't get CLSID for olesrvr.OleSrv!");
		OleUninitialize();
		return 1;
	}

	/*
	**	Create an instance of the OleSrv object.
	*/
	hr = CoCreateInstance(clsid, NULL, CLSCTX_SERVER, IID_IUnknown,
		(void FAR* FAR*)&punk);
	if (FAILED(hr))
	{
		
		debuglog("Can't create instance of olesrvr.OleSrv object! %d\n",
			hr);
		errormsg("Can't create instance of olesrvr.OleSrv object!");
		OleUninitialize();
		return 1;
	}

	/*
	**	Get a pointer to the OleSrv IDispatch interface.
	*/
	hr = punk->QueryInterface(IID_IDispatch, (void FAR* FAR*)&olesrv);
	if (FAILED(hr))
	{
		debuglog("Can't get pointer to OleSrv idispatch intf!\n");
		errormsg("Can't get pointer to OleSrv idispatch intf!");
		OleUninitialize();
		return 1;
	}

	punk->Release();	//Release - no longer needed.

	/*
	**	Invoke the ms2pdf method.
	*/
	DISPID dispid1;
	DISPPARAMS disp1;
	VARIANTARG varg1[5];
	BSTR szName;
	if (strcmp(ftype, "visio") == 0)
	{
		szName = L"visio2ps";
	}
	else if (strcmp(ftype, "msword") == 0)
	{
		szName = L"word2ps";
	}
	else if (strcmp(ftype, "mspwpt") == 0)
	{
		szName = L"pwpt2ps";
	}
	else if (strcmp(ftype, "msexcl") == 0)
	{
		szName = L"excl2ps";
	}
	else if (strcmp(ftype, "msproj") == 0)
	{
		szName = L"proj2ps";
	}
	else if (strcmp(ftype, "msbinder") == 0)
	{
		szName = L"binder2ps";
	}
	else if (strcmp(ftype, "frame") == 0
		|| strcmp(ftype, "frame_book") == 0)
	{
		szName = L"frame2pdf";
	}
	else
	{
		debuglog("Wrong name <%s> for olesrvr.OleSrv method!\n", ftype);
		errormsg("Wrong name <%s> for olesrvr.OleSrv method!", ftype);
		OleUninitialize();
		return 1;
	}
	int MaxParms = 2;
	int i;

	for(i = 0; i < MaxParms; i++)
	{
		VariantInit(&varg1[i]);
	}

	/*
	*/
	OLECHAR FAR* Omsfile = makeOLEstring(msfile);
	V_VT(&varg1[1])      = VT_BSTR;
	V_BSTR(&varg1[1])    = SysAllocString(Omsfile);

	OLECHAR FAR* Opdffile = makeOLEstring(pdffile);
	V_VT(&varg1[0])      = VT_BSTR;
	V_BSTR(&varg1[0])    = SysAllocString(Opdffile);

	disp1.rgvarg = varg1;
	disp1.rgdispidNamedArgs = NULL;
	disp1.cArgs = MaxParms;
	disp1.cNamedArgs = 0;

	/*
	**	Get ID for ms2pdf method.
	*/
	hr = olesrv->GetIDsOfNames(IID_NULL, &szName, 1, LOCALE_SYSTEM_DEFAULT,
		&dispid1);
	if (FAILED(hr))
	{
		debuglog("Can't get ID for %s method!\n", ftype);
		errormsg("Can't get ID for %s method!", ftype);
		OleUninitialize();
		return 1;
	}

	hr = olesrv->Invoke(dispid1, IID_NULL, LOCALE_SYSTEM_DEFAULT,
		DISPATCH_METHOD, &disp1, NULL, NULL, NULL);

	if (hr == S_OK)
	{
		debuglog("%s: OK.\n", ftype);
	}
	else
	{
		if (hr == DISP_E_BADPARAMCOUNT)
		{
			debuglog("%s: bad parameter count.\n", ftype);
			errormsg("%s: bad parameter count.", ftype);
		}
		else if (hr == DISP_E_BADVARTYPE)
		{
			debuglog("%s: arg is invalid variant type.\n", ftype);
			errormsg("%s: arg is invalid variant type.", ftype);
		}
		else if (hr == DISP_E_EXCEPTION)
		{
			debuglog("%s: caught an exception.\n", ftype);
			errormsg("%s: caught an exception.", ftype);
		}
		else if (hr == DISP_E_MEMBERNOTFOUND)
		{
			debuglog("%s: member nonexistent or improper value.\n",
				ftype);
			errormsg("%s: member nonexistent or improper value.",
				ftype);
		}
		else if (hr == DISP_E_NONAMEDARGS)
		{
			debuglog("%s: named args not supported.\n", ftype);
			errormsg("%s: named args not supported.\n", ftype);
		}
		else if (hr == DISP_E_OVERFLOW)
		{
			debuglog(
			     "%s: a value could not be converted to type.\n",
		 	     ftype);
			errormsg(
			     "%s: a value could not be converted to type.",
		 	     ftype);
		}
		else if (hr == DISP_E_PARAMNOTFOUND)
		{
			debuglog("%s: parameter is invalid.\n", ftype);
			errormsg("%s: parameter is invalid.", ftype);
		}
		else if (hr == DISP_E_TYPEMISMATCH)
		{
			debuglog("%s: arg can't be coerced.\n", ftype);
			errormsg("%s: arg can't be coerced.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNINTERFACE)
		{
			debuglog("%s: can't get this error msg.\n", ftype);
			errormsg("%s: can't get this error msg.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNLCID)
		{
			debuglog("%s: unrecognized local id.\n", ftype);
			errormsg("%s: unrecognized local id.", ftype);
		}
		else if (hr == DISP_E_PARAMNOTOPTIONAL)
		{
			debuglog("%s: a required param was omitted.\n", ftype);
			errormsg("%s: a required param was omitted.", ftype);
		}
		else if (hr == DISP_E_UNKNOWNNAME)
		{
			debuglog("%s: unknown name.\n", ftype);
			errormsg("%s: unknown name.", ftype);
		}
		else if (hr == DISP_E_BADINDEX)
		{
			debuglog("%s: bad index.\n", ftype);
			errormsg("%s: bad index.", ftype);
		}
		else if (hr == DISP_E_ARRAYISLOCKED)
		{
			debuglog("%s: array is locked.\n", ftype);
			errormsg("%s: array is locked.", ftype);
		}
		else if (hr == DISP_E_BADCALLEE)
		{
			debuglog("%s:  bad callee.\n", ftype);
			errormsg("%s:  bad callee.", ftype);
		}
		else if (hr == DISP_E_NOTACOLLECTION)
		{
			debuglog("%s: not a collection.\n", ftype);
			errormsg("%s: not a collection.", ftype);
		}
		else 
		{
			debuglog("%s:  some crazy return!\n", ftype);
			errormsg("%s:  some crazy return!", ftype);
		}

		olesrv->Release();
		OleUninitialize();
		return 1;
	}

	for (i = 0; i < MaxParms; i++)
	{
		VariantClear(&varg1[i]);
	}

	olesrv->Release();
	OleUninitialize();
	return 0;
}

void oleAbort()
{
	if (olesrv != NULL)
	{
		olesrv->Release();
	}
	OleUninitialize();
}

OLECHAR* makeOLEstring(char* string)
{
	static OLECHAR achW[100];
	MultiByteToWideChar(CP_ACP, 0, string,
		-1, achW, 100);
	return achW;
}
