
/*
**	name:	olesrvr
**
**	purpose:
**		Convert an MS Word document to PDF
**
**	Setup:	Should be run on a Windows machine where MS Office 97
**		has been installed.  The Adobe Acrobat PDF Writer must
**		be installed.  This service can only be run with 
**		Exceed Inetd.
*/
#include "stdafx.h"
#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <mmsystem.h>
#include "debuglog.h"
#include "netsock.h"
#include "hcllib.h"	//  Exceed Inetd lib
#include "defines.h"
#include "Tempnam.h"


char	lgsys[50];
char	logn[50];
char	from_type[50];
char	password[50];
char	compasid[20];
int	debug = 0;
int	Network = TRUE;
netsock	*Client = NULL;

char	mailCmd[1000];

VOID CALLBACK MyTimer(HWND, UINT, UINT, DWORD);
extern int lock();
extern void unlock();
extern void init_debuglog(void);
extern void oleAbort();
extern int ms2pdf(char*, char*, char*);
extern int diffVer(char*, char*, char*, char*);
extern int getErrorMsg(char*);
extern int makeErrorFile(char*);
extern int makeError2File(char*);

int PASCAL WinMain(HINSTANCE hInst, HINSTANCE hPrevInst, LPSTR lpszCmdLine,
	int cmdShow)
{
	int	ret;
	char	buf[10000];
	SOCKET	Sock;
	WSADATA	wsdata;
	
	strcpy(lgsys, "none");
	strcpy(logn, "yet");
	strcpy(compasid, "unknown");
	init_debuglog();

 	strcpy(mailCmd, "c:\\olesrvr\\sm /x:");

	WSAStartup(0x0101, &wsdata);
	Sock = InitInetd(lpszCmdLine);
	if (Sock == SOCKET_ERROR)
	{
		debuglog("Must be run from Exceed Inetd.\n");
		WSACleanup();
		ShutdownInetd();
		return(1);
	}

	/*
	**	This is a network server.
	*/
	Client = new netsock(Sock);

	/*
	**	get data from the client - 
	**		- system name (server coming from)
	**		- user
	**		- access password
	**		- debug
	**		- conversion type
	**		- compasid (optional)
	*/

	if (Client->RecvMsg() == ERR)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}

	/*
	**	getToken pulls these out in forward order
	*/
	char *token = Client->getToken();
	if (!token)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}
	strcpy(lgsys, token);  // system

	token = Client->getToken();
	if (!token)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}
	strcpy(logn, token);      // user

	token = Client->getToken();
	if (!token)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}
	strcpy(password, token);  // password

	token = Client->getToken();
	if (!token)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}
	debug = atoi(token);      // debug

	token = Client->getToken();
	if (!token)
	{
		debuglog( "Read failed on network msg, %d, exiting...\n",
			errno);
		Client->Abort("Invalid syntax on oleServer call.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}
	strcpy(from_type, token); // type

	token = Client->getToken();
	if (token)
	{
		strcpy(compasid, token); // prodid
	}
	/*
	**	Check for authorized use of server
	*/
	if (strcmp(password, "forCOMPAS") != 0)
	{
		debuglog("User is not authorized!\n");
		Client->Abort("You are not authorized to use the OLE Server.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}

	debuglog("Starting olesrvr for ID %s...\n", compasid);

	/*
	**	Tempnam on Win95 gets into trouble and reused process ids
	**	so have to use this function.
	*/
	char msfile[500];
	Tempnam(msfile);

	ret = Client->RecvFile(msfile);
	if(ret != 0)
	{
		debuglog("Error receiving %s file!\n", from_type);
		Client->Abort("Error receiving file on OLE Server.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		exit(1);
	}

	char msfile2[500];
	if(!strcmp(from_type, "msdiff"))
	{
		Tempnam(msfile2);

		ret = Client->RecvFile(msfile2);
		if(ret != 0)
		{
			debuglog("Error receiving %s file!\n", from_type);
			Client->Abort("Error receiving file on OLE Server.");
			delete Client;

			WSACleanup();
			ShutdownInetd();
			exit(1);
		}
	}	
	/*
	**	We can only allow one conversion at a time since
	**	we have to set the file name in PDF Writer ini file.
	*/
	Client->StatusMsg("Starting the OLE Server...");

	int sent = 0;
	while (!lock())
	{
		if (!sent) 
		{
			debuglog("waiting for a process to finish...\n");
		}
		Sleep(500);  // milliseconds
		sent = 1;
	}

	/*
	**	Set timer to go off after 10 minutes.
	*/
	UINT mills = 600000;  // 10 minutes
	if (timeSetEvent(mills, 1000, (LPTIMECALLBACK) MyTimer, NULL, 
		TIME_ONESHOT) == 0)
	{

		debuglog("Can't set timer.\n");
		Client->Abort("Can't set timer on OLE Server.");
		delete Client;

		WSACleanup();
		ShutdownInetd();
		unlock();
		exit(1);
	}

	/*
	**	Set the output PDF file name into PDF Writer
	**	initialization file.
	*/
	char pdffile[500];
	Tempnam(pdffile);

	sprintf(buf, "Starting %s.", from_type);
	debuglog("%s\n", buf);
	Client->StatusMsg(buf);
	if(!strcmp(from_type, "msdiff"))
	{
		ret = diffVer(from_type, msfile, msfile2, pdffile);
	}
	else
	{	
		ret = ms2pdf(from_type, msfile, pdffile);
	}
	if (ret != 0)
	{
		unlock();
		if (getErrorMsg(buf) < 0)
		{
			Client->Abort(
				"Error converting your document to PDF.");
			debuglog("Trouble in %s.ms2pdf (%s) - exiting.\n",
				from_type, msfile);
		}
		else
		{
			Client->Abort(buf);
		}
		delete Client;

		WSACleanup();
		ShutdownInetd();
		char tbuf[100];
		sprintf(tbuf, 
		"\r\n\r\nUser is %s, User System is %s, txttype is %s, id is %s\r\n", 
			logn, lgsys, from_type, compasid);
		strcat(buf, tbuf);
		makeErrorFile(buf);
		strcat(mailCmd, "c:\\olesrvr\\MsgH1");
		system(mailCmd);
		exit(1);
	}

	/*
	**	Remove the log file generated by distiller for
	**	this document.
	*/
	char* ptr;
	strcpy(buf, pdffile);
	if ((ptr = strchr(buf, '.')) == NULL)
	{
		sprintf(buf, "%s.log", pdffile);
	}
	else
	{
		strcpy(ptr+1, "log");
	}
	unlink(buf);
	//unlink("c:\\distout.ps");
	unlock();

	/*
	**	Now send the PDF file back to the client.
	*/
	ret = Client->SendFile(pdffile);
	if(ret != 0)
	{
		debuglog("Can't send the formatted file to client.\n");
		Client->Abort("Can't send formatted File.");
		delete Client;

		WSACleanup();
		ShutdownInetd();

		char tbuf[100];
		strcpy(buf, "Can't send the formatted file to client.");
		sprintf(tbuf, 
			"\r\nUser is %s, User System is %s, txttype is %s, compasid is %s\r\n\r\n", 
			logn, lgsys, from_type, compasid);
		strcat(buf, tbuf);
		makeErrorFile(buf);
		strcat(mailCmd, "c:\\olesrvr\\MsgH1");
		system(mailCmd);
		exit(1);
	}
	Client->StatusMsg("OLE Server done.");
	unlink(msfile);
	unlink(pdffile);

	delete Client;
	WSACleanup();
	ShutdownInetd();
	return (0);
}

VOID CALLBACK MyTimer(HWND hwnd, UINT msg, UINT idTimer, DWORD dwTimer)
{
	unlock();
	oleAbort();
	debuglog("olesrvr: timed out after 10 minutes!\n");
	Client->Abort("OLE Server Timed out trying to format document.");
	delete Client;
	WSACleanup();
	ShutdownInetd();

	char tbuf[100];
	char buf[10000];
	strcpy(buf, "OLE Server Timed out trying to format this document.");
	sprintf(tbuf, 
		"\r\nUser is %s, User System is %s, txttype is %s, compasid is %s\r\n\r\n", 
		logn, lgsys, from_type, compasid);
	strcat(buf, tbuf);
	makeError2File(buf);
	strcat(mailCmd, "c:\\olesrvr\\MsgH2");
	system(mailCmd);
	exit(1);
}
